==> knox-2.0.0-src.zip: knox-2.0.0/gateway-util-common/src/main/java/org/apache/knox/gateway/plang/Arity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.plang;

import java.util.List;

public interface Arity {
    void check(String function, List<?> params);
    Arity UNARY = Arity.of(1);
    Arity BINARY = Arity.of(2);

    static Arity of(int count) {
        return (methodName, params) -> {
            if (params.size() != count) {
                throw new ArityException(methodName, count, params.size());
            }
        };
    }
    static Arity min(int count) {
        return (methodName, params) -> {
            if (params.size() < count) {
                throw new ArityException("wrong number of arguments in call to '" + methodName
                        + "'. Expected at least " + count + " got " + params.size() + ".");
            }
        };
    }
}

==> knox-2.1.0-src.zip: knox-2.1.0/gateway-util-common/src/main/java/org/apache/knox/gateway/plang/Arity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.plang;

import java.util.List;

public interface Arity {
    void check(String function, List<?> params);
    Arity UNARY = Arity.of(1);
    Arity BINARY = Arity.of(2);

    static Arity of(int count) {
        return (methodName, params) -> {
            if (params.size() != count) {
                throw new ArityException(methodName, count, params.size());
            }
        };
    }
    static Arity min(int count) {
        return (methodName, params) -> {
            if (params.size() < count) {
                throw new ArityException("wrong number of arguments in call to '" + methodName
                        + "'. Expected at least " + count + " got " + params.size() + ".");
            }
        };
    }

    static Arity even() {
        return (methodName, params) -> {
            if (params.size() % 2 != 0) {
                throw new ArityException("wrong number of arguments in call to '" + methodName
                        + "'. Expected even number of arguments, got " + params.size() + ".");
            }
        };
    }

    static Arity between(int min, int max) {
        return (methodName, params) -> {
            if (params.size() < min || params.size() > max) {
                throw new ArityException("wrong number of arguments in call to '" + methodName
                        + "'. Expected at least " + min + ", at max " + max + " arguments, got " + params.size() + ".");
            }
        };
    }
}
